# coding: utf-8
# Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20230831


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateMaintenanceWindowDetails(object):
    """
    Maintenance Window information to be updated.
    """

    #: A constant which can be used with the maintenance_window_type property of a UpdateMaintenanceWindowDetails.
    #: This constant has a value of "OPEN_ENDED"
    MAINTENANCE_WINDOW_TYPE_OPEN_ENDED = "OPEN_ENDED"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateMaintenanceWindowDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateMaintenanceWindowDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateMaintenanceWindowDetails.
        :type description: str

        :param maintenance_window_type:
            The value to assign to the maintenance_window_type property of this UpdateMaintenanceWindowDetails.
            Allowed values for this property are: "OPEN_ENDED"
        :type maintenance_window_type: str

        :param is_outage:
            The value to assign to the is_outage property of this UpdateMaintenanceWindowDetails.
        :type is_outage: bool

        :param time_schedule_start:
            The value to assign to the time_schedule_start property of this UpdateMaintenanceWindowDetails.
        :type time_schedule_start: datetime

        :param duration:
            The value to assign to the duration property of this UpdateMaintenanceWindowDetails.
        :type duration: str

        :param is_recurring:
            The value to assign to the is_recurring property of this UpdateMaintenanceWindowDetails.
        :type is_recurring: bool

        :param recurrences:
            The value to assign to the recurrences property of this UpdateMaintenanceWindowDetails.
        :type recurrences: str

        :param task_initiation_cutoff:
            The value to assign to the task_initiation_cutoff property of this UpdateMaintenanceWindowDetails.
        :type task_initiation_cutoff: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateMaintenanceWindowDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateMaintenanceWindowDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'maintenance_window_type': 'str',
            'is_outage': 'bool',
            'time_schedule_start': 'datetime',
            'duration': 'str',
            'is_recurring': 'bool',
            'recurrences': 'str',
            'task_initiation_cutoff': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'maintenance_window_type': 'maintenanceWindowType',
            'is_outage': 'isOutage',
            'time_schedule_start': 'timeScheduleStart',
            'duration': 'duration',
            'is_recurring': 'isRecurring',
            'recurrences': 'recurrences',
            'task_initiation_cutoff': 'taskInitiationCutoff',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._maintenance_window_type = None
        self._is_outage = None
        self._time_schedule_start = None
        self._duration = None
        self._is_recurring = None
        self._recurrences = None
        self._task_initiation_cutoff = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateMaintenanceWindowDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        Example: `My new resource`


        :return: The display_name of this UpdateMaintenanceWindowDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateMaintenanceWindowDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        Example: `My new resource`


        :param display_name: The display_name of this UpdateMaintenanceWindowDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdateMaintenanceWindowDetails.
        A user-friendly description. To provide some insight about the resource.
        Avoid entering confidential information.


        :return: The description of this UpdateMaintenanceWindowDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateMaintenanceWindowDetails.
        A user-friendly description. To provide some insight about the resource.
        Avoid entering confidential information.


        :param description: The description of this UpdateMaintenanceWindowDetails.
        :type: str
        """
        self._description = description

    @property
    def maintenance_window_type(self):
        """
        Gets the maintenance_window_type of this UpdateMaintenanceWindowDetails.
        MaintenanceWindow Identifier

        Allowed values for this property are: "OPEN_ENDED"


        :return: The maintenance_window_type of this UpdateMaintenanceWindowDetails.
        :rtype: str
        """
        return self._maintenance_window_type

    @maintenance_window_type.setter
    def maintenance_window_type(self, maintenance_window_type):
        """
        Sets the maintenance_window_type of this UpdateMaintenanceWindowDetails.
        MaintenanceWindow Identifier


        :param maintenance_window_type: The maintenance_window_type of this UpdateMaintenanceWindowDetails.
        :type: str
        """
        allowed_values = ["OPEN_ENDED"]
        if not value_allowed_none_or_none_sentinel(maintenance_window_type, allowed_values):
            raise ValueError(
                f"Invalid value for `maintenance_window_type`, must be None or one of {allowed_values}"
            )
        self._maintenance_window_type = maintenance_window_type

    @property
    def is_outage(self):
        """
        Gets the is_outage of this UpdateMaintenanceWindowDetails.
        Does the maintenenace window cause outage?


        :return: The is_outage of this UpdateMaintenanceWindowDetails.
        :rtype: bool
        """
        return self._is_outage

    @is_outage.setter
    def is_outage(self, is_outage):
        """
        Sets the is_outage of this UpdateMaintenanceWindowDetails.
        Does the maintenenace window cause outage?


        :param is_outage: The is_outage of this UpdateMaintenanceWindowDetails.
        :type: bool
        """
        self._is_outage = is_outage

    @property
    def time_schedule_start(self):
        """
        Gets the time_schedule_start of this UpdateMaintenanceWindowDetails.
        Start time of schedule


        :return: The time_schedule_start of this UpdateMaintenanceWindowDetails.
        :rtype: datetime
        """
        return self._time_schedule_start

    @time_schedule_start.setter
    def time_schedule_start(self, time_schedule_start):
        """
        Sets the time_schedule_start of this UpdateMaintenanceWindowDetails.
        Start time of schedule


        :param time_schedule_start: The time_schedule_start of this UpdateMaintenanceWindowDetails.
        :type: datetime
        """
        self._time_schedule_start = time_schedule_start

    @property
    def duration(self):
        """
        Gets the duration of this UpdateMaintenanceWindowDetails.
        Duration if schedule type is Custom


        :return: The duration of this UpdateMaintenanceWindowDetails.
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """
        Sets the duration of this UpdateMaintenanceWindowDetails.
        Duration if schedule type is Custom


        :param duration: The duration of this UpdateMaintenanceWindowDetails.
        :type: str
        """
        self._duration = duration

    @property
    def is_recurring(self):
        """
        Gets the is_recurring of this UpdateMaintenanceWindowDetails.
        Is this is a recurring maintenance window


        :return: The is_recurring of this UpdateMaintenanceWindowDetails.
        :rtype: bool
        """
        return self._is_recurring

    @is_recurring.setter
    def is_recurring(self, is_recurring):
        """
        Sets the is_recurring of this UpdateMaintenanceWindowDetails.
        Is this is a recurring maintenance window


        :param is_recurring: The is_recurring of this UpdateMaintenanceWindowDetails.
        :type: bool
        """
        self._is_recurring = is_recurring

    @property
    def recurrences(self):
        """
        Gets the recurrences of this UpdateMaintenanceWindowDetails.
        Recurrence rule specification if recurring


        :return: The recurrences of this UpdateMaintenanceWindowDetails.
        :rtype: str
        """
        return self._recurrences

    @recurrences.setter
    def recurrences(self, recurrences):
        """
        Sets the recurrences of this UpdateMaintenanceWindowDetails.
        Recurrence rule specification if recurring


        :param recurrences: The recurrences of this UpdateMaintenanceWindowDetails.
        :type: str
        """
        self._recurrences = recurrences

    @property
    def task_initiation_cutoff(self):
        """
        Gets the task_initiation_cutoff of this UpdateMaintenanceWindowDetails.
        Task initiation cutoff


        :return: The task_initiation_cutoff of this UpdateMaintenanceWindowDetails.
        :rtype: int
        """
        return self._task_initiation_cutoff

    @task_initiation_cutoff.setter
    def task_initiation_cutoff(self, task_initiation_cutoff):
        """
        Sets the task_initiation_cutoff of this UpdateMaintenanceWindowDetails.
        Task initiation cutoff


        :param task_initiation_cutoff: The task_initiation_cutoff of this UpdateMaintenanceWindowDetails.
        :type: int
        """
        self._task_initiation_cutoff = task_initiation_cutoff

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateMaintenanceWindowDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateMaintenanceWindowDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateMaintenanceWindowDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateMaintenanceWindowDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateMaintenanceWindowDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateMaintenanceWindowDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateMaintenanceWindowDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateMaintenanceWindowDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
