## Tag Resources in Tenancy

Tag Resources in Tenancy is a tool to help you tag resources easily, it uses the OCI Python SDK. 
It covers the below OCI components, 
Authentication by User or Compute using instance principals, 
Output can be printer friendly, Summary or JSON.

**Developed by Adi Zohar, Nov 2020-Mar 2024**

## Modules Included:  
- oci.core.VirtualNetworkClient          
- oci.core.ComputeClient                 
- oci.core.BlockstorageClient            
- oci.object_storage.ObjectStorageClient 
- oci.database.DatabaseClient            
- oci.load_balancer.LoadBalancerClient   
- oci.identity.IdentityClient

** DISCLAIMER – This is not an official Oracle application

## Executing using Cloud Shell:
```
1. install oci sdk package
   pip3 install --user oci

2. clone the oci sdk repo
   git clone https://github.com/oracle/oci-python-sdk

3. run with delegation token
   cd oci-python-sdk/examples/tag_resources_in_tenancy
   python3 tag_resources_in_tenancy.py --help
```

## OCI Authentication using User - Privilges can be aligned accordingly
Required OCI IAM user with manage privileges to the compartment you aim to tag

```
ALLOW GROUP ReadOnlyUsers to manage all-resources IN TENANCY
```

## Installation of Python 3 incase you don't have Python3 installed:
Please follow Python Documentation - https://docs.python.org/3/using/index.html

## Install oci SDK Packages:
Please follow Oracle Python SDK Documentation - https://github.com/oracle/oci-python-sdk

## Copy the Software
Download the tag_resources_in_tenancy.py from this project  

Execute  

```
$ python3 tag_resources_in_tenancy.py --help

usage: tag_resources_in_tenancy.py [-h] [-t CONFIG_PROFILE] [-p PROXY] [-cp COMPARTMENT] [-rg REGION] [-ip] [-dt] [-tag TAG] [-tagseperator TAGSEPERATOR]
                                   [-action {add_defined,add_free,del_defined,del_free,list}] [-output {list,json,summary}] [-service SERVICE]
                                   [-filter_by_name FILTER_BY_NAME]

optional arguments:
  -h, --help                                                show this help message and exit
  -t CONFIG_PROFILE                                         Config file section to use (tenancy profile)
  -p PROXY                                                  Set Proxy (i.e. www-proxy-server.com:80)
  -cp COMPARTMENT                                           Filter by Compartment Name or Id
  -rg REGION                                                Filter by Region Name
  -ip                                                       Use Instance Principals for Authentication
  -dt                                                       Use Delegation Token for Authentication
  -tag TAG                                                  Tags in format - namespace.key=value or key=value with comma seperator for multi tags
  -tagseperator TAGSEPERATOR                                Tag Seperator for multiple tags, default=,
  -action {add_defined,add_free,del_defined,del_free,list}  Action Type
  -output {list,json,summary}                               Output type, default=summary
  -service SERVICE                                          Services = all,compute,block,network,identity,loadbalancer,database,object,file. default=all
  -filter_by_name FILTER_BY_NAME                            Filter service by name, comma seperator for multi names
```

## My Other Projects

- [ShowOCI](https://github.com/oracle/oci-python-sdk/tree/master/examples/showoci)

- [ShowUsage](https://github.com/oracle/oci-python-sdk/tree/master/examples/showusage)

- [ShowSubscription](https://github.com/oracle/oci-python-sdk/tree/master/examples/showsubscription)

- [ShowRewards](https://github.com/oracle/oci-python-sdk/tree/master/examples/showrewards)

- [List Resources in Tenancy](https://github.com/oracle/oci-python-sdk/tree/master/examples/list_resources_in_tenancy)

- [Object Storage Tools](https://github.com/oracle/oci-python-sdk/tree/master/examples/object_storage)

- [Usage2ADW](https://github.com/oracle-samples/usage-reports-to-adw)

## Example Execution for adding defined Tags:
```
python3 tag_resources_in_tenancy.py -action add_defined -tag BillingNS.Division=TEST -cp TestCompartment -rg us-ashburn-1 

Connecting to Identity Service...
Loading Compartments...
    Total 1 compartments loaded.

##########################################################################################
#                                 Running Tag Resources                                  #
##########################################################################################
Written By Adi Zohar, Feb 2022
Starts at 2022-02-03 12:33:40
Command Line  : -cp Test -rg us-ashburn-1 -action add_defined -tag project.desc=description of the project,project.team=Team A
Tag 1         : project.desc=description of the project
Tag 2         : project.team=Team A
Tag Seperator : ,
Tenant Name   : orasenatdpltdevopsnetw02
Tenant Id     : ocid1.tenancy.oc1..aaaaaaaaxtkkpxc5qwgpwx7y2wt5pinegyzea4uacnmck7iamsssjvw4s3bq

Reading Tag Namespaces...
   Found Tag Namespace 'project', id = ocid1.tagnamespace.oc1..aaaaaaaaofnh6y66knfqxg3ihjd53e2olhotnetsisoxxxxx
   Found Tag Key 'desc', id = ocid1.tagdefinition.oc1..aaaaaaaakvoslxfyen744cotrkdrv4hrlwrs3rqd3uhr64hmfxxxxxxx
   Found Tag Namespace 'project', id = ocid1.tagnamespace.oc1..aaaaaaaaofnh6y66knfqxg3ihjd53e2olhotnetsisoxxxxx
   Found Tag Key 'team', id = ocid1.tagdefinition.oc1..aaaaaaaauvpkmmewoxifdaih4g2p5u6j7m5xvsujeelsoha4xxxxxxxx

Processing Regions...

Region us-ashburn-1...
    Compartment Test
        Instances              - 1     Tag Added = 0         Tag Updated = 1       Tag Exist = 1
        Boot Volumes           - 1     Tag Added = 0         Tag Updated = 1       Tag Exist = 1
        Boot Volumes Backups   - 7     Tag Added = 0         Tag Updated = 7       Tag Exist = 7
        Block Volumes          - (-)
        Block Volumes Backups  - (-)
        Volume Groups          - (-)
        Volume Groups Backup   - (-)
        Network VCNs           - 4     Tag Added = 0         Tag Updated = 4       Tag Exist = 4
        Network Subnets        - 6     Tag Added = 0         Tag Updated = 6       Tag Exist = 6
        Network CPEs           - 1     Tag Added = 0         Tag Updated = 1       Tag Exist = 1
        Network DHCPs          - 4     Tag Added = 0         Tag Updated = 4       Tag Exist = 4
        Network IGWs           - 3     Tag Added = 0         Tag Updated = 3       Tag Exist = 3
        Network IPSECs         - 1     Tag Added = 0         Tag Updated = 1       Tag Exist = 1
        Network LPGs           - 2     Tag Added = 0         Tag Updated = 2       Tag Exist = 2
        Network NATGWs         - 2     Tag Added = 0         Tag Updated = 2       Tag Exist = 2
        Network RPGs           - 1     Tag Added = 0         Tag Updated = 1       Tag Exist = 1
        Network Routes         - 8     Tag Added = 0         Tag Updated = 8       Tag Exist = 8
        Network SLs            - 5     Tag Added = 0         Tag Updated = 5       Tag Exist = 5
        Network SGWs           - 2     Tag Added = 0         Tag Updated = 2       Tag Exist = 2
        Network VCircuit       - (-)
        Load Balancers         - 2     Tag Added = 0         Tag Updated = 2       Tag Exist = 2
        DB DB Systems          - 1     Tag Added = 0         Tag Updated = 1       Tag Exist = 1
        DB Autonomous          - 1     Tag Added = 0         Tag Updated = 1       Tag Exist = 1
        Object Storage Buckets - 2     Tag Added = 0         Tag Updated = 2       Tag Exist = 2

##########################################################################################
#                                     Output as List                                     #
##########################################################################################
us-ashburn-1 | Test             | Instances                | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Boot Volumes             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Boot Volumes Backups     | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Boot Volumes Backups     | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Boot Volumes Backups     | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Boot Volumes Backups     | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Boot Volumes Backups     | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Boot Volumes Backups     | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Boot Volumes Backups     | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network VCNs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network VCNs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network VCNs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network VCNs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Subnets          | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Subnets          | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Subnets          | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Subnets          | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Subnets          | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Subnets          | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network CPEs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network DHCPs            | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network DHCPs            | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network DHCPs            | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network DHCPs            | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network IGWs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network IGWs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network IGWs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network IPSECs           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network LPGs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network LPGs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network NATGWs           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network NATGWs           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network RPGs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Routes           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Routes           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Routes           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Routes           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Routes           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Routes           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Routes           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network Routes           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network SLs              | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network SLs              | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network SLs              | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network SLs              | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network SLs              | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network SGWs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Network SGWs             | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Load Balancers           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Load Balancers           | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | DB DB Systems            | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | DB Autonomous            | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Object Storage Buckets   | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...
us-ashburn-1 | Test             | Object Storage Buckets   | Added: 0     | Updated: 1   | Deleted: 0   | Exist: 1     | ...

##########################################################################################
#                            Completed at 2022-02-03 12:34:21                            #
##########################################################################################

```
